==> babel-preset-doctolib-1.2.0.tgz: package/index.js <==
module.exports = {
  plugins: [
    // additional plugins
    require('babel-plugin-transform-runtime'),
    require('babel-plugin-syntax-object-rest-spread'),
    require('babel-plugin-transform-object-rest-spread'),
    require('babel-plugin-syntax-class-properties'),
    require('babel-plugin-transform-class-properties'),

    // es2015
    [require('babel-plugin-transform-es2015-template-literals'), {loose: true}],
    require('babel-plugin-transform-es2015-literals'),
    require('babel-plugin-transform-es2015-function-name'),
    require('babel-plugin-transform-es2015-arrow-functions'),
    require('babel-plugin-transform-es2015-block-scoped-functions'),
    [require('babel-plugin-transform-es2015-classes'), {loose: true}],
    require('babel-plugin-transform-es2015-object-super'),
    require('babel-plugin-transform-es2015-shorthand-properties'),
    [require('babel-plugin-transform-es2015-computed-properties'), {loose: true}],
    [require('babel-plugin-transform-es2015-for-of'), {loose: true}],
    require('babel-plugin-transform-es2015-sticky-regex'),
    require('babel-plugin-transform-es2015-unicode-regex'),
    require('babel-plugin-transform-es2015-constants'),
    [require('babel-plugin-transform-es2015-spread'), {loose: true}],
    require('babel-plugin-transform-es2015-parameters'),
    [require('babel-plugin-transform-es2015-destructuring'), {loose: true}],
    require('babel-plugin-transform-es2015-block-scoping'),
    require('babel-plugin-transform-es2015-typeof-symbol'),
    [require('babel-plugin-transform-es2015-modules-commonjs'), {loose: true}],
    [require('babel-plugin-transform-regenerator'), {async: false, asyncGenerators: false}],

    // react
    require('babel-plugin-transform-react-jsx'),
    require('babel-plugin-syntax-jsx')
  ],

  env: {
    production: {
      plugins: [
        // react runtime optimizations
        require('babel-plugin-transform-react-remove-prop-types').default,
        require('babel-plugin-transform-react-constant-elements')
      ]
    }
  }
};

==> babel-preset-doctolib-2.0.0.tgz: package/index.js <==
module.exports = {
  plugins: [
    // additional plugins
    require('babel-plugin-syntax-object-rest-spread'),
    require('babel-plugin-transform-object-rest-spread'),
    require('babel-plugin-syntax-class-properties'),
    require('babel-plugin-transform-class-properties'),

    // es2015
    [require('babel-plugin-transform-es2015-template-literals'), {loose: true}],
    require('babel-plugin-transform-es2015-literals'),
    require('babel-plugin-transform-es2015-function-name'),
    require('babel-plugin-transform-es2015-arrow-functions'),
    require('babel-plugin-transform-es2015-block-scoped-functions'),
    [require('babel-plugin-transform-es2015-classes'), {loose: true}],
    require('babel-plugin-transform-es2015-object-super'),
    require('babel-plugin-transform-es2015-shorthand-properties'),
    [require('babel-plugin-transform-es2015-computed-properties'), {loose: true}],
    [require('babel-plugin-transform-es2015-for-of'), {loose: true}],
    require('babel-plugin-transform-es2015-sticky-regex'),
    require('babel-plugin-transform-es2015-unicode-regex'),
    require('babel-plugin-transform-es2015-constants'),
    [require('babel-plugin-transform-es2015-spread'), {loose: true}],
    require('babel-plugin-transform-es2015-parameters'),
    [require('babel-plugin-transform-es2015-destructuring'), {loose: true}],
    require('babel-plugin-transform-es2015-block-scoping'),
    require('babel-plugin-transform-es2015-typeof-symbol'),
    [require('babel-plugin-transform-es2015-modules-commonjs'), {loose: true}],
    [require('babel-plugin-transform-regenerator'), {async: false, asyncGenerators: false}],

    // react
    require('babel-plugin-transform-react-jsx'),
    require('babel-plugin-syntax-jsx')
  ],

  env: {
    production: {
      plugins: [
        // react runtime optimizations
        require('babel-plugin-external-helpers'),
        require('babel-plugin-transform-react-remove-prop-types').default,
        require('babel-plugin-transform-react-constant-elements'),
        require('babel-plugin-transform-react-inline-elements')
      ]
    }
  }
};
